@@ -1,6 +1,5 @@
 import requests
 import base64
-import urllib.parse
 
 
 def send_get_json(url, proxy=""):
@@ -37,10 +36,6 @@ def get_base64(text):
     return base64.b64encode(text.encode()).decode()
 
 
-def get_base64_url(text):
-    return urllib.parse.quote(base64.b64encode(text.encode()).decode())
-
-
 def get_file_content_as_base64(path):
     """
     获取文件base64编码
